@@ -249,8 +249,8 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
             "func": "approve",
             "chainId": chain_id_mapping[chain.lower()],
             'contract': token,
-            'to': spender_address,
-            'amount': float(amount),
+            '_spender': spender_address,
+            '_value': float(amount),
             'abi': erc20_approve_abi
           }
           action_data = ActionData(func='', group='', params=action_params)
@@ -277,7 +277,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
           next_action_data = ActionData(func='transfer', group='transfer', params=next_params)
           next_action = Action(msg=None, type='backend', data=next_action_data.__dict__)
           return {
-            'result': { "code": 401, "content": "Insufficient allowance, proceeding with approval." },
+            'result': { "code": 200, "content": "Insufficient allowance, proceeding with approval." },
             'action': action.__dict__,
             'next_action': next_action.__dict__
           }
@@ -365,7 +365,8 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
               info = {"content": f"Cannot find {receiver} on contact", "code": 420}
               return {
                 'result': info,
-                'action': None, 'next_action': None
+                'action': None, 
+                'next_action': None
               }
           value = float(amount)
           receiver = res
@@ -381,7 +382,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
           next_action = Action(msg=None, type='backend', data=next_action_data.__dict__)
 
           return {
-            'result': { 'code': 403, 'content': 'Incorrect network, switching to the correct network for you.' },
+            'result': { 'code': 200, 'content': 'Incorrect network, switching to the correct network for you.' },
             'action': action.__dict__,
             'next_action': next_action.__dict__
           }
@@ -406,9 +407,9 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
             'run_mode': run_mode
           }
           action_data = ActionData(func='transfer', group='transfer', params=params)
-          action = Action(msg=None, type='backend', data=action_data.__dict__)
+          action = Action(msg=None, type='wallet', data=action_data.__dict__)
           return {
-            'result': None,
+            'result': { "code": 200, "content": "" },
             'action': action.__dict__,
             'next_action': None
           }
